pub fn encode_string(s: &str) -> Vec<SingleDisplayData> ⓘExpand description
Encodes each char of a string to its bit-representation. The resulting vector should be understood as the data to be displayed on a display chain that is as long as the coupled/chained displays that are powered by the MAX7219. So if you have 4 displays and 10 chars then you could only display indices zero to three and bit shift all rows one to the left per iteration. This way you get a smooth transition/animation. Don’t forget about the sleep-timeout per iteration!